==> fillets-ng-data_0.7.1.orig.tar.gz: fillets-ng-data-0.7.1/script/elevator1/dialogs_pl.lua <==

dialogId("zd1-v-civil", "font_big", "What a glorious civilization. So many centuries under water and their elevators still work.")
dialogStr("To musiała być wspaniała cywilizacja. Stulecia pod wodą, a winda wciąż działa.")


dialogId("zd1-m-tlac", "font_small", "Especially, when we push them.")
dialogStr("Tak, szczególnie jak ją popchnąć.")


dialogId("zd1-m-dolu", "font_small", "But only down.")
dialogStr("Ale tylko w dół.")


dialogId("zd1-m-last", "font_small", "Do you see that shell?")
dialogStr("Widzisz tę muszelkę?")


dialogId("zd1-v-talis", "font_big", "It`s an age-old talisman for elevator builders who always said 'Build well. Build with Shell`.")
dialogStr("To prastary talizman budowniczych wind, których motto brzmiało 'Buduj dobrze, buduj z Shellem`.")


dialogId("zd1-m-poved", "font_small", "Isn`t that shell a little bit familiar?")
dialogStr("Czy ta muszelka nie wygląda ci znajomo?")


dialogId("zd1-v-styd", "font_big", "They should be ashamed of themselves. This is subliminal advertising.")
dialogStr("Powinni się wstydzić. To jest kryptoreklama!")


dialogId("zd1-v-lebka", "font_big", "That skull looks familiar.")
dialogStr("Ta czaszka wygląda znajomo.")


dialogId("zd1-m-stejne", "font_small", "All human skulls look the same... Unlike fish skeletons.")
dialogStr("Wszystkie ludzkie czaszki wyglądają tak samo. Nie to, co rybie.")


dialogId("zd1-m-cesta", "font_small", "This is a tough path.")
dialogStr("Ciężka sprawa.")


dialogId("zd1-v-krecek", "font_big", "I feel like a mouse on a treadmill.")
dialogStr("Czuję się jak mysz w kieracie.")


dialogId("zd1-m-slap", "font_small", "A treadmill for fish? But we only have fins.")
dialogStr("Rybi kierat? Przecież my mamy tylko płetwy.")


dialogId("zd1-x-huhu1", "font_lightgrey", "Hoo, hooooo, hoooo... I`m over heeeere...")
dialogStr("Hu huuu huuuuu... Tu jestem...")


dialogId("zd1-x-huhu2", "font_lightgrey", "Hoooo, if you want I`ll tell you how to solve all the levels...")
dialogStr("Huuu... jeśli chcecie, mogę wam powiedzieć, jak rozwiązać wszystkie poziomy...")


dialogId("zd1-x-huhu3", "font_lightgrey", "Hooo, ho, hooo, I know why the city sank!")
dialogStr("Huuuu hu huuuu... wiem, dlaczego zatonęło miasto!")


dialogId("zd1-x-huhu4", "font_lightgrey", "Hoooo, why isn`t anyone paying attention to me?")
dialogStr("Huuuu... dlaczego nikt nie zwraca na mnie uwagi??")


dialogId("zd1-x-huhu5", "font_lightgrey", "Hoooo ho hooo! Why are you ignoring me?")
dialogStr("Huuuu hu huuu huuu! Dlaczego mnie ignorujecie?")


dialogId("zd1-x-huhu6", "font_lightgrey", "Hooooo, hooooo, fish! Pay attention to me!")
dialogStr("Hahuuu, holahuuuu, ryby! Spójrzcie na mnie!")

==> fillets-ng-data_0.8.0.orig.tar.gz: fillets-ng-data-0.8.0/script/elevator1/dialogs_pl.lua <==

dialogId("zd1-v-civil", "font_big", "What a glorious civilization. So many centuries under water and their elevators still work.")
dialogStr("To musiała być wspaniała cywilizacja. Stulecia pod wodą, a winda wciąż działa.")


dialogId("zd1-m-tlac", "font_small", "Especially, when we push them.")
dialogStr("Tak, szczególnie jak ją popchnąć.")


dialogId("zd1-m-dolu", "font_small", "But only down.")
dialogStr("Ale tylko w dół.")


dialogId("zd1-m-last", "font_small", "Do you see that shell?")
dialogStr("Widzisz tę muszelkę?")


dialogId("zd1-v-talis", "font_big", "It’s an age-old talisman for elevator builders who always said 'Build well. Build with Shell’.")
dialogStr("To prastary talizman budowniczych wind, których motto brzmiało 'Buduj dobrze, buduj z Shellem’.")


dialogId("zd1-m-poved", "font_small", "Isn’t that shell a little bit familiar?")
dialogStr("Czy ta muszelka nie wygląda ci znajomo?")


dialogId("zd1-v-styd", "font_big", "They should be ashamed of themselves. This is subliminal advertising.")
dialogStr("Powinni się wstydzić. To jest kryptoreklama!")


dialogId("zd1-v-lebka", "font_big", "That skull looks familiar.")
dialogStr("Ta czaszka wygląda znajomo.")


dialogId("zd1-m-stejne", "font_small", "All human skulls look the same... Unlike fish skeletons.")
dialogStr("Wszystkie ludzkie czaszki wyglądają tak samo. Nie to, co rybie.")


dialogId("zd1-m-cesta", "font_small", "This is a tough path.")
dialogStr("Ciężka sprawa.")


dialogId("zd1-v-krecek", "font_big", "I feel like a mouse on a treadmill.")
dialogStr("Czuję się jak mysz w kieracie.")


dialogId("zd1-m-slap", "font_small", "A treadmill for fish? But we only have fins.")
dialogStr("Rybi kierat? Przecież my mamy tylko płetwy.")


dialogId("zd1-x-huhu1", "font_lightgrey", "Hoo, hooooo, hoooo... I’m over heeeere...")
dialogStr("Hu huuu huuuuu... Tu jestem...")


dialogId("zd1-x-huhu2", "font_lightgrey", "Hoooo, if you want I’ll tell you how to solve all the levels...")
dialogStr("Huuu... jeśli chcecie, mogę wam powiedzieć, jak rozwiązać wszystkie poziomy...")


dialogId("zd1-x-huhu3", "font_lightgrey", "Hooo, ho, hooo, I know why the city sank!")
dialogStr("Huuuu hu huuuu... wiem, dlaczego zatonęło miasto!")


dialogId("zd1-x-huhu4", "font_lightgrey", "Hoooo, why isn’t anyone paying attention to me?")
dialogStr("Huuuu... dlaczego nikt nie zwraca na mnie uwagi??")


dialogId("zd1-x-huhu5", "font_lightgrey", "Hoooo ho hooo! Why are you ignoring me?")
dialogStr("Huuuu hu huuu huuu! Dlaczego mnie ignorujecie?")


dialogId("zd1-x-huhu6", "font_lightgrey", "Hooooo, hooooo, fish! Pay attention to me!")
dialogStr("Hahuuu, holahuuuu, ryby! Spójrzcie na mnie!")
